
#include <Wire.h>
#include "ESP8266WiFi.h"

// according to STA326 datasheet, the i2c adress should be 0x34
// but for some reason, on the FX Audio D802 it is 0x1A
#define STA326	0x1A		// adress of the STA326

void setup()
{
	Wire.begin(2, 0);			// enable i2c
	Wire.setClock(400000L);		// 400kHz seems to be more reliable

	// doing some output to uart
	Serial.begin(115200);
	Serial.println("\n\nFX Audio D802/D802C auto mute fix!");

	WiFi.forceSleepBegin();		// switch off WIFI

	delay(5000);		// wait 5s

	// the trick happens here
	byte data = 0;

	Serial.print("\nReading STA326 conf D register: ");
	Wire.beginTransmission(STA326);
	Wire.write(0x03);				// STA326 conf D register
	Wire.endTransmission();
	Wire.requestFrom(STA326, 1);	// request 1 byte
	data = Wire.read();				// read data
	Serial.println(data, HEX);

	Serial.print("\nClearing ZDE bit (auto mute): ");
	data = data & 0b10111111;		// clear ZDE
	Wire.beginTransmission(STA326);
	Wire.write(0x03);				// STA326 conf D register
	Wire.write(data);				// write 
	Wire.endTransmission();

	// read again to test if ZDE still is disabled
	delay(100);
	Wire.beginTransmission(STA326);
	Wire.write(0x03);				// STA326 conf D register
	Wire.endTransmission();
	Wire.requestFrom(STA326, 1);	// request 1 byte
	data = Wire.read();				// read data

	// test if ZDE bit is 0
	data = data & 0b01000000;
	if (data == 0)
		Serial.println("OK.");
	else
		Serial.println("Found a problem, auto mute still active!!");
}

void loop()
{
	delay(500);
	Serial.println("\nGoing to sleep.");
	ESP.deepSleep(0, WAKE_RF_DISABLED);		// sleep forever and disable WIFI forever
	delay(100);
}

